# Installation and optional packages
## Jupyter notebooks, vscode integration


# Typical usage within jupyter notebooks

## Loading files

### Example snippet 

## ioniq's heirarchical data structure with ranked subdivision

## Filtering, trimming voltage spikes
### example snippet
## parsers


## visualization and plotting traces

### Interactive visualization

## Exporting features and tables: Pandas
### feature extraction utility function

### visualization of features

# Batch processing
